SseReconnectOptions

Struct SseReconnectOptions 

pub struct SseReconnectOptions {
    pub retry: RetryOptions,
    pub reconnect_on_eof: bool,
    pub honor_server_retry: bool,
    pub server_retry_max_delay: Option<Duration>,
    pub apply_jitter_to_server_retry: bool,
}
Reconnect behavior options for crate::HttpClient::execute_sse_with_reconnect.

Fields

retry: RetryOptions

Retry options used by SSE reconnect delay calculation.

max_attempts includes the initial stream-open attempt, so if callers want at most N reconnects they should pass max_attempts = N + 1.

reconnect_on_eof: bool

Whether to reconnect when the SSE stream ends without an explicit error.

honor_server_retry: bool

Whether to honor SSE retry: field as the next reconnect delay.

server_retry_max_delay: Option<Duration>

Optional upper bound applied to SSE retry: delay values from server events.

When None, reconnect runner derives a cap from retry delay strategy when it has explicit max (Random / Exponential), otherwise it uses internal default bound.

apply_jitter_to_server_retry: bool

Whether jitter should be applied when the reconnect delay comes from SSE retry: field.

Implementations

Source

impl SseReconnectOptions

pub fn new() -> Self

Creates default SSE reconnect options.

Returns

Same as SseReconnectOptions::default.