pub struct HttpLogger<'a> { /* private fields */ }Expand description
HTTP logger bound to one pair of logging options and sensitive header policy.
Implementations
Sourceimpl<'a> HttpLogger<'a>
impl<'a> HttpLogger<'a>
Sourcepub fn new(options: &'a HttpClientOptions) -> Self
pub fn new(options: &'a HttpClientOptions) -> Self
Sourcepub fn log_request(&self, request: &HttpRequest)
pub fn log_request(&self, request: &HttpRequest)
Sourcepub fn log_response(&self, response: &HttpResponse)
pub fn log_response(&self, response: &HttpResponse)
Sourcepub fn log_stream_response_headers(&self, response_meta: &HttpResponseMeta)
pub fn log_stream_response_headers(&self, response_meta: &HttpResponseMeta)
Sourcepub fn is_trace_enabled(&self) -> bool
pub fn is_trace_enabled(&self) -> bool
Returns whether TRACE logs should be emitted under current options and subscriber state.
Returns
true when logging is enabled and TRACE is active.