SensitiveQueryParams

Struct SensitiveQueryParams 

pub struct SensitiveQueryParams { /* private fields */ }
Set of query parameter names whose values should be masked.

Names are matched case-insensitively and common _ / - separators are ignored, so access_token, access-token, and accessToken are equivalent.

Implementations

Source

impl SensitiveQueryParams

pub fn new() -> Self

Creates an empty set.

Returns

Empty SensitiveQueryParams.

pub fn contains(&self, name: &str) -> bool

Returns whether name is sensitive.

Parameters
  • name: Query parameter name.
Returns

true if the value should be masked in logged URLs.

pub fn insert(&mut self, name: &str)

Inserts one query parameter name.

Parameters
  • name: Query parameter name to mark sensitive.
pub fn extend<I, S>(&mut self, names: I)
where I: IntoIterator<Item = S>, S: AsRef<str>,

Inserts many query parameter names.

Parameters
  • names: Query parameter names to mark sensitive.
pub fn clear(&mut self)

Clears all names.

pub fn len(&self) -> usize

Returns the number of stored query parameter names.

Returns

Stored query parameter count.

pub fn is_empty(&self) -> bool

Returns whether no query parameter names are stored.

Returns

true when empty.

pub fn iter(&self) -> impl Iterator<Item = &str>

Iterates canonical query parameter names.

Returns

Iterator over stored canonical query parameter names.