pub type HttpByteStream = Pin<Box<dyn Stream<Item = HttpResult<Bytes>> + Send>>;Expand description
Pin-boxed async stream of body chunks or errors, used by crate::HttpResponse.
Aliased Type
pub struct HttpByteStream { /* private fields */ }pub type HttpByteStream = Pin<Box<dyn Stream<Item = HttpResult<Bytes>> + Send>>;Pin-boxed async stream of body chunks or errors, used by crate::HttpResponse.
pub struct HttpByteStream { /* private fields */ }