HttpResponseInterceptor

Type Alias HttpResponseInterceptor 

pub type HttpResponseInterceptor = ArcMutatingFunction<HttpResponseInterceptorContext, HttpResult<()>>;
Response interceptor function used to inspect/mutate response metadata before the response is returned to callers.

The interceptor receives HttpResponseInterceptorContext, where status and request method are immutable and headers/final URL are mutable.

Returning Err short-circuits execution for the current attempt.

Aliased Type

pub struct HttpResponseInterceptor { /* private fields */ }